@@ -1,5 +1,5 @@
 ;;;
-;;; $Id: irchat-commands.el,v 1.18 1994/08/17 13:46:25 tmo Exp tmo $
+;;; $Id: irchat-commands.el,v 1.1 1995/01/15 11:43:37 tmo Exp tmo $
 ;;;
 ;;; see file irchat-copyright.el for change log and copyright info
 
@@ -9,15 +9,6 @@
   (require 'irchat-dcc)
   (require 'gnus-caesar))
 
-(defvar irchat-query-client-nick nil)
-(defvar irchat-query-client-version nil)
-(defvar irchat-query-client-userinfo nil)
-(defvar irchat-query-client-help nil)
-(defvar irchat-query-client-clientinfo nil)
-(defvar irchat-query-client-lastcommand nil)
-(defvar irchat-query-client-alist nil)
-(defvar irchat-query-client-insert-to-generic nil)
-
 
 (defun irchat-Command-describe-briefly ()
   (message (substitute-command-keys "Type \\[describe-mode] for help")))
@@ -29,15 +20,20 @@
   (interactive "P")
   (if (irchat-frozen irchat-Dialogue-buffer)
       (irchat-freeze-toggle irchat-Dialogue-buffer))
+  (if (irchat-ownfrozen irchat-Dialogue-buffer)
+      (irchat-ownfreeze-toggle irchat-Dialogue-buffer))
   (setq irchat-freeze nil)
   (setq irchat-freeze-indicator "-")
+  (setq irchat-ownfreeze nil)
+  (setq irchat-ownfreeze-indicator "-")
   (if (irchat-get-buffer-window irchat-Dialogue-buffer)
       nil
     (if (one-window-p)
 	(irchat-configure-windows)
       (display-buffer irchat-Dialogue-buffer)))
   (set-buffer irchat-Dialogue-buffer)
-  (set-window-point (irchat-get-buffer-window irchat-Dialogue-buffer) (point-max)))
+  (set-window-point (irchat-get-buffer-window irchat-Dialogue-buffer) 
+		    (point-max)))
 
 
 (defun irchat-Command-pollnames ()
@@ -66,40 +62,68 @@
 
 
 (defun irchat-Command-keepalive ()
-  (irchat-squeeze-forceflush)
   (if (not (irchat-server-opened))
       (irchat 'always)))
 
 
+(defun irchat-compose-servertimestring (s)
+  (let* ((w '(("Mon" "Monday") ("Tue" "Tuesday") ("Wed" "Wednesday") 
+	      ("Thu" "Thursday") ("Fri" "Friday") ("Sat" "Saturday") 
+	      ("Sun" "Sunday")))
+	 (m '(("Jan" "January") ("Feb" "February") ("Mar" "March") 
+	      ("Apr" "April") ("May" "May") ("Jun" "June")  ("Jul" "July") 
+	      ("Aug" "August") ("Sep" "September") ("Oct" "October") 
+	      ("Nov" "November") ("Dec" "December")))
+	 (wdat) (mnam)
+	 (wabb (substring s 0 3))
+	 (mabb (substring s 4 7)))
+    (setq wdat (car (cdr (assoc wabb w)))
+	  mnam (car (cdr (assoc mabb m))))
+    (format "%s %s %s %s %s" 
+	    wdat mnam (substring s 8 10) (substring s 20 24)
+	    (substring s 11 16))))
+
+
 (defun irchat-Command-timestamp ()
   (interactive)
   (let ((stamp (format "%s" (format irchat-timestamp-format
-				    (current-time-string)))))
+				    (if irchat-format-time-function
+					(apply irchat-format-time-function
+					       (list (current-time-string)))
+				      (current-time-string))))))
     (irchat-Dialogue-insert stamp)))
 
 
 (defun irchat-Command-send-message (message)
   "Send MESSAGE to current chat partner of current channel."
-  (if (eq irchat-command-buffer-mode 'chat)
-      (if irchat-current-chat-partner
-	  (progn
-	    (irchat-send "PRIVMSG %s :%s" irchat-current-chat-partner message)
-	    (irchat-own-message (format (format "%s %%s"
-						irchat-format-string)
-					irchat-current-chat-partner message)))
-	(message 
-	 (substitute-command-keys 
-	  "Type \\[irchat-Command-join] to start private conversation")))
-    (if (not irchat-current-channel)
-	(progn
-	  (beep t)
-	  (message 
-	   (substitute-command-keys 
-	    "Type \\[irchat-Command-join] to join a channel")))
-      (irchat-send "PRIVMSG %s :%s" irchat-current-channel message)
-      (irchat-own-message
-       (format (format (format "%s %%%%s" irchat-myformat-string) 
-		       irchat-nickname) message)))))
+  (if (> (length message) 0)
+      (progn
+	(if (eq irchat-command-buffer-mode 'chat)
+	    (if irchat-current-chat-partner
+		(progn
+		  (irchat-send "PRIVMSG %s :%s" 
+			       irchat-current-chat-partner message)
+		  (irchat-own-private-message 
+		   (format (format "%s %%s"
+				   irchat-format-string)
+			   irchat-current-chat-partner message)))
+	      (message 
+	       (substitute-command-keys 
+		"Type \\[irchat-Command-join] to start private conversation")))
+	  (if (not irchat-current-channel)
+	      (progn
+		(beep t)
+		(message 
+		 (substitute-command-keys 
+		  "Type \\[irchat-Command-join] to join a channel")))
+	    (irchat-send "PRIVMSG %s :%s" irchat-current-channel message)
+	    (irchat-own-message
+	     (format (format (format "%s %%%%s" irchat-myformat-string) 
+			     irchat-nickname) message))))
+	t)
+    (progn
+      (message "IRCHAT: NO text to send")
+      nil)))
 
 
 (defun irchat-Command-enter-message ()
@@ -111,8 +135,9 @@ current channel."
     (setq start (point))
     (end-of-line)
     (setq message (buffer-substring start (point)))
-    (irchat-next-line 1)
-    (irchat-Command-send-message message)))
+    (if (irchat-Command-send-message message)
+	(irchat-next-line 1))))
+
 
 
 (defun irchat-Dialogue-enter-message ()
@@ -163,7 +188,6 @@ If user nicname is given, join the same set of channels as
 the specified user. 
 If Command-buffer is in chat-mode, start private conversation 
 with specified user."
-
   (interactive (let (join-channel-var (completion-ignore-case t))
 		 (setq join-channel-var 
 		       (if (eq irchat-command-buffer-mode 'chat)
@@ -199,7 +223,8 @@ with specified user."
 	  (if (and (car (car nicks))
 		   (string-ci-equal join-channel-var (car (car nicks))))
 	      (setq join-channel-var
-		    (or (car (get (intern (car (car nicks))) 'chnl))
+		    (or (car (get (intern (car (car nicks)) irchat-obarray) 
+ 				  'chnl))
 			join-channel-var)
 		    found t))
 	  (setq nicks (cdr nicks))))
@@ -261,9 +286,9 @@ with specified user."
 			'(lambda (s) t) nil nil))
 		 (list kill-nickname-var)))
   (if (string= "" kill-nickname-var)
-      (let ((buf (current-buffer)))
+      (let ((buf (current-buffer))
+	    (buffer-read-only))
 	(set-buffer irchat-Dialogue-buffer)
-	(setq buffer-read-only nil)
 	(goto-char (point-max))
 	(irchat-w-insert irchat-D-buffer "*** Currently ignored people:")
 	(let ((mylist irchat-kill-nickname))
@@ -271,13 +296,14 @@ with specified user."
 	    (irchat-w-insert irchat-D-buffer (format " %s" (car mylist)))
 	    (setq mylist (cdr mylist))))
 	(irchat-w-insert irchat-D-buffer "\n")
-	(setq buffer-read-only t)
 	(set-buffer buf)))
-  (if (memq (intern kill-nickname-var) irchat-kill-nickname)
+  (if (memq (intern kill-nickname-var irchat-obarray) irchat-kill-nickname)
       (setq irchat-kill-nickname 
-	    (delq (intern kill-nickname-var) irchat-kill-nickname))
+	    (delq (intern kill-nickname-var irchat-obarray) 
+		  irchat-kill-nickname))
     (setq irchat-kill-nickname 
-	  (cons (intern kill-nickname-var) irchat-kill-nickname))))
+	  (cons (intern kill-nickname-var irchat-obarray) 
+		irchat-kill-nickname))))
 
 
 (defun irchat-Command-send-action (&optional private)
@@ -308,7 +334,7 @@ with specified user."
 		   irchat-current-channel)
 		 message)
     (if private
-	(irchat-own-message (format "*** Action to %s: %s %s"
+	(irchat-own-private-message (format "*** Action to %s: %s %s"
 				    irchat-privmsg-partner irchat-nickname
 				    message))
       (irchat-own-message (format "*** Action: %s %s" irchat-nickname
@@ -358,9 +384,7 @@ With - as argument, list all channels."
 (defun irchat-Command-modec (change)
   "Send a MODE command"
   (interactive "sMode for this channel: ")
-  (irchat-send "MODE %s %s"
-	       irchat-current-channel
-	       change))
+  (irchat-send "MODE %s %s" irchat-current-channel change))
 
 
 (defun irchat-Command-message (message-nick-var message)
@@ -376,7 +400,7 @@ With - as argument, list all channels."
 			(format "Private message to %s: " message-nick-var)))))
   (setq irchat-privmsg-partner message-nick-var)
   (irchat-send "PRIVMSG %s :%s" message-nick-var message)
-  (irchat-own-message 
+  (irchat-own-private-message 
    (format (format "%s %%s" irchat-format-string) message-nick-var message)))
 
 
@@ -398,9 +422,13 @@ With - as argument, list all channels."
     (setq stop (point))
     (setq message (buffer-substring start stop))
     (irchat-next-line 1)
-    (irchat-send "PRIVMSG %s :%s" irchat-privmsg-partner message)
-    (irchat-own-message (format (format "%s %%s" irchat-format-string) 
-				irchat-privmsg-partner message))))
+    (if (> (length message) 0)
+	(progn
+	  (irchat-send "PRIVMSG %s :%s" irchat-privmsg-partner message)
+	  (irchat-own-private-message 
+	   (format (format "%s %%s" irchat-format-string) 
+		   irchat-privmsg-partner message)))
+      (message "IRCHAT: No text to send"))))
 
 
 (defun irchat-Command-names (&optional channel)
@@ -428,9 +456,13 @@ With - as argument, list all channels."
 (defun irchat-Command-nickname (nick)
   "Set your nickname."
   (interactive "sEnter your nickname: ")
-  (setq irchat-old-nickname irchat-nickname)
-  (setq irchat-nickname (irchat-read-nickname nick))
-  (irchat-send "NICK %s" nick))
+  (let ((nickname (irchat-read-nickname nick)))
+    (if (not (= (length nickname) 0))
+	(progn 
+	  (setq irchat-old-nickname irchat-nickname)
+	  (setq irchat-nickname nickname)
+	  (irchat-send "NICK %s" nick))
+      (message "IRCHAT: illegal nickname \"%s\"; not changed" nickname))))
 
 
 (defun irchat-Command-who (&optional expr)
@@ -466,9 +498,9 @@ be a string to send NICK upon entering."
 	  (if (string= greeting "")
 	      (setq greeting nil))
 	  (list nick greeting)))
-  (put (intern nick) 'irchat-waited-for t)
+  (put (intern nick irchat-obarray) 'irchat-waited-for t)
   (if greeting 
-      (put (intern nick) 'irchat-greeting greeting)))
+      (put (intern nick irchat-obarray) 'irchat-greeting greeting)))
 
 
 (defun irchat-Command-finger (finger-nick-var)
@@ -556,6 +588,18 @@ be a string to send NICK upon entering."
   )
 
 
+(defun irchat-Command-ownfreeze ()
+  "Toggle the automatic scrolling of the Dialogue window when user sends messages."
+  (interactive)
+  (if (irchat-ownfrozen (car irchat-D-buffer))
+      (setq irchat-ownfreeze-indicator "-")
+    (setq irchat-ownfreeze-indicator "M"))
+  (switch-to-buffer (current-buffer))
+  (setq irchat-ownfreeze (not irchat-ownfreeze))
+  (irchat-ownfreeze-toggle (car irchat-D-buffer))
+  )
+
+
 (defun irchat-Command-quit (&optional quit-msg)
   "Quit IRCHAT."
   (interactive "P")
@@ -579,9 +623,10 @@ be a string to send NICK upon entering."
 	    (delete-other-windows))
 	(irchat-close-server)
 	(run-hooks 'irchat-Exit-hook)
-	(setq irchat-polling 0)
-	(setq irchat-current-channel nil)
-	(setq irchat-current-channels nil))))
+	(setq irchat-polling 0
+	      irchat-current-channel nil
+	      irchat-obarray nil
+	      irchat-current-channels nil))))
 
 
 (defun irchat-Command-generic (message)
@@ -696,6 +741,8 @@ be sent to the server.  For a list of messages, see irchat-Command-generic."
 	 "What info: " 
 	 irchat-query-client-alist '(lambda (s) t) nil 
 	 irchat-query-client-lastcommand))
+  (if (string-ci-equal irchat-query-client-lastcommand "ping")
+      (setq irchat-ctcp-ping-time (current-time)))
   (irchat-send "PRIVMSG %s :%s%s"
 	       client-generic-nick-var
 	       irchat-query-client-lastcommand
@@ -709,6 +756,7 @@ be sent to the server.  For a list of messages, see irchat-Command-generic."
 	(read-from-minibuffer "New userinfo: "
 			      irchat-client-userinfo)))
 
+
 (defun irchat-Command-client-userinfo-from-commandbuffer ()
   "Ask about someones client clientinfo."
   (interactive)
@@ -791,7 +839,6 @@ be sent to the server.  For a list of messages, see irchat-Command-generic."
   (end-of-line)
   (gnus-caesar-region n))
 
-
 ;;;
 ;;;
 ;;;
@@ -853,9 +900,11 @@ be sent to the server.  For a list of messages, see irchat-Command-generic."
 ;;;
 (defun irchat-Command-eod-buffer ()
   (interactive)
-  (let ((saved-buffer (current-buffer)))
+  (let ((saved-buffer (current-buffer))
+	(dialogue-window (irchat-get-buffer-window irchat-Dialogue-buffer)))
     (set-buffer irchat-Dialogue-buffer)
     (goto-char (point-max))
+    (set-window-point dialogue-window (point-max))
     (set-buffer saved-buffer)))
 
 ;;;
@@ -996,10 +1045,12 @@ mode, the current channel and current chat partner are not altered)"
 ;;;
 ;;; dig last kill from KILLS and show it
 ;;;
+
 (defun irchat-Command-show-last-kill ()
   (interactive)
   (save-excursion
     (let ((buf (current-buffer))
+	  (buffer-read-only)
 	  str)
       (set-buffer irchat-KILLS-buffer)
       (goto-char (point-max))
@@ -1008,17 +1059,18 @@ mode, the current channel and current chat partner are not altered)"
       (goto-char (point-max))
       (set-buffer irchat-Dialogue-buffer)
       (goto-char (point-max))
-      (setq buffer-read-only nil)
       (irchat-w-insert irchat-D-buffer str)
       (goto-char (point-max))
-      (setq buffer-read-only t)
       (set-window-point (irchat-get-buffer-window irchat-Dialogue-buffer)
 			(point-max))
       (set-buffer buf))))
 
+
 (defun irchat-Command-toggle-private ()
   (interactive)
-  (let ((irchat-private-window (get-buffer-window (car (last irchat-P-buffer)))))
+  (let ((irchat-private-window 
+	 (get-buffer-window 
+	  (car (list (nth (- (length irchat-P-buffer) 1) irchat-P-buffer))))))
     (if irchat-private-window
 	(if (interactive-p)
 	    (let* ((my-IN-win (get-buffer-window irchat-Command-buffer))
@@ -1043,18 +1095,27 @@ mode, the current channel and current chat partner are not altered)"
 	    (condition-case err
 		(progn
 		  (split-window-vertically)
-		  (shrink-window (- (window-height) irchat-private-window-height))
-		  (set-window-buffer 
-		   (get-buffer-window irchat-Dialogue-buffer)
-		   (irchat-get-buffer-create (car (last irchat-P-buffer)))))
+		  (if irchat-swap-private
+		      (progn
+			(shrink-window 
+			 (- irchat-private-window-height (window-height)))
+			(other-window 1)
+			(set-window-buffer 
+			 (get-buffer-window irchat-Dialogue-buffer)
+			 (irchat-get-buffer-create 
+			  (nth (- (length irchat-P-buffer) 1)
+			       irchat-P-buffer))))
+		    (shrink-window 
+		     (- (window-height) irchat-private-window-height))
+		    (set-window-buffer 
+		     (get-buffer-window irchat-Dialogue-buffer)
+		     (irchat-get-buffer-create
+		      (nth (- (length irchat-P-buffer) 1)
+			   irchat-P-buffer)))))
 	      (args-out-of-range 
 	       (message "IRCHAT: Command-window-toggle with too small window")))
-	    (select-window sw))
-	)
-      )
-    )
-  (irchat-w-insert irchat-D-buffer "") ;; recenter if needed
-  )
+	    (select-window sw)))))
+  (irchat-w-insert irchat-D-buffer "")) ;; recenter if needed
 
 ;;;
 ;;; eof
