@@ -1,5 +1,5 @@
 ;;;
-;;; $Id: irchat-globals.el,v 1.7 1994/08/17 13:46:25 tmo Exp tmo $
+;;; $Id: irchat-globals.el,v 1.2 1995/01/15 11:43:37 tmo Exp tmo $
 ;;;
 ;;; see file irchat-copyright.el for change log and copyright info
 
@@ -15,10 +15,10 @@
 (defconst irchat-client-version-major "2"
   "Major version number. Major functional changes change this number.")
 
-(defconst irchat-client-version-minor "45"
+(defconst irchat-client-version-minor "49"
   "Minor version number. Server Protocol changes and bug fixes change this number.")
 
-(defconst irchat-client-version-release "$Date: 1994/12/24 00:01:00 $"
+(defconst irchat-client-version-release "$Date: 1995/01/15 15:38:02 $"
   "version release date")
 
 (defconst irchat-client-name "Irchat"
@@ -74,6 +74,9 @@ we cannot change to new nick")
 (defvar irchat-current-channel nil
   "The channel you currently have joined.")
 
+(defvar irchat-current-topic nil
+  "The topic of current channel.")
+
 (defvar irchat-current-channels nil
   "The channels you have currently joined.")
 
@@ -141,13 +144,52 @@ a greeting telling what version of IRCHAT this is.")
 (defconst irchat-privmsg 'privmsg)
 (defconst irchat-killmsg 'kill)
 (defconst irchat-ignoredmsg 'ignore)
-
-(defvar irchat-squeeze-info nil)
-(defvar irchat-squeeze-needflush nil)
-
 (defvar irchat-nick-accepted nil)
 
+(defconst irchat-obarray-size 631
+  "*The size of obarray used by irchat on channelname and username space.
+For efficiency this should be prime. See documentation of intern and 
+make-vector for more information. Here is a list of some small primes...    
+
+13, 29, 37, 47, 59, 71, 89, 107, 131, 163, 197, 239, 293, 353, 431, 521, 
+631, 761, 919, 1103, 1327, 1597, 1931, 2333, 2801, 3371, 4049, 4861, 5839, 
+7013, 8419, 10103, 12143, 14591, 17519, 21023, 25229, 30293, 36353, 
+43627, 52361, 62851, 75431, 90523, 108631, 130363, 156437, 187751, 
+225307, 270371, 324449, 389357, 467237, 560689, 672827, 807403, 968897,
+1162687, 1395263, 1674319, 2009191, 2411033, 2893249.")
+
+(defvar irchat-obarray (make-vector irchat-obarray-size nil))
+
 (defvar irchat-ctcp-ping-time (list 0 0 0))
+
+
+(defvar irchat-query-client-lastcommand nil
+  "*Place to keep last entered command")
+
+(defvar irchat-query-client-nick nil
+  "*Place to keep last queried nick")
+
+(defvar irchat-query-client-alist
+  '(("VERSION") ("CLIENTINFO") ("HELP") ("DCC") ("USERINFO") ("PING")))
+
+(defconst irchat-query-client-insert-to-generic
+  "")
+
+(defconst irchat-query-client-version
+  (concat "VERSION" irchat-query-client-insert-to-generic))
+
+(defconst irchat-query-client-userinfo
+  (concat "USERINFO" irchat-query-client-insert-to-generic))
+
+(defconst irchat-query-client-help
+  (concat "HELP" irchat-query-client-insert-to-generic))
+
+(defconst irchat-query-client-clientinfo
+  (concat "CLIENTINFO" irchat-query-client-insert-to-generic))
+
+(defconst irchat-query-client-ping
+  (concat "PING" irchat-query-client-insert-to-generic))
+
 ;;;
 ;;;  eof
 ;;; 
