@@ -1,5 +1,5 @@
 ;;;
-;;; $Id: irchat-main.el,v 1.7 1994/08/17 13:46:25 tmo Exp tmo $
+;;; $Id: irchat-main.el,v 1.1 1995/01/15 11:43:37 tmo Exp tmo $
 ;;;
 ;;; see file irchat-copyright.el for change log and copyright info
 
@@ -34,6 +34,7 @@ Else it is put at the bottom."))
 
 (mapcar (function
 	 (lambda (sym)
+	   ;; not interned at irchat-obarray to get completing reads.
 	   (eval (list 'defvar (intern (concat "irchat-"
 					       (prin1-to-string sym)
 					       "-hook"))
@@ -308,7 +309,6 @@ If the stream is opened, return T, otherwise return NIL."
    (list nil (function irchat-Command-timestamp) irchat-timestamp-interval)
    (list nil (function irchat-Command-pollnames) irchat-pollnames-interval)
    (list nil (function irchat-Command-keepalive) irchat-keepalive-interval)
-   (list nil (function irchat-squeeze-forceflush) irchat-squeeze-interval)
    (list nil (function irchat-check-buffers) irchat-checkbuffer-interval)
    )
   "Symbol name to store timer, timer-function and timer-interval.")
@@ -332,7 +332,8 @@ If already connected, just pop up the windows."
 	;; IRC server is successfully open. 
 	(setq mode-line-process (format " {%s}" irchat-server))
 	(let ((buffer-read-only nil))
-	  (erase-buffer)
+	  (if (not irchat-keep-buffers)
+	      (erase-buffer))
 	  (sit-for 0))
 	(irchat-Dialogue-setup-buffer)
 	(irchat-KILLS-setup-buffer)
@@ -345,7 +346,9 @@ If already connected, just pop up the windows."
 	  (if irchat-startup-channel
 	      (irchat-Command-join irchat-startup-channel)))
 	(run-hooks 'irchat-Startup-hook)
-	(setq irchat-timers
+	(setq 
+	 irchat-obarray (make-vector irchat-obarray-size nil)
+	 irchat-timers
 	      (mapcar 
 	       (function 
 		(lambda (timer)
@@ -412,7 +415,8 @@ Instead, these commands are available:
 
   (use-local-map irchat-Dialogue-mode-map)
   (buffer-disable-undo (current-buffer))
-  (erase-buffer)
+  (if (not irchat-keep-buffers) 
+      (erase-buffer))
   (set-buffer irchat-Dialogue-buffer)
   (setq buffer-read-only t)
   (run-hooks 'irchat-Dialogue-mode-hook))
@@ -574,7 +578,8 @@ One is for entering commands and text, the other displays the IRC dialogue."
 	  (irchat-w-replace (car buffer) match defstring oldstring newstring)
 	  (setq buffer (cdr buffer))))
     (let* ((obuf (current-buffer))
-	   (bufintern (intern (format "%s" (irchat-get-buffer-create buffer))))
+	   (bufintern (intern (format "%s" (irchat-get-buffer-create buffer)) 
+			      irchat-obarray))
 	   (narrow (get bufintern 'narrow))
 	   (frozen (get bufintern 'frozen))
 	   (spoint nil))
@@ -597,27 +602,36 @@ One is for entering commands and text, the other displays the IRC dialogue."
 	    (irchat-w-insert buffer ""))
 	(irchat-w-insert buffer defstring)))))
 
+
 (defun irchat-w-insert (buffer string)
-  (if irchat-squeeze-needflush
-      (irchat-squeeze-flush))
   (if (or (not buffer) (listp buffer))
       (while buffer
 	(progn
 	  (irchat-w-insert (car buffer) string)
-	  (setq buffer (cdr buffer))
-	  ))
+	  (setq buffer (cdr buffer))))
     (let* ((obuf (current-buffer))
-	   (bufintern (intern (format "%s" (irchat-get-buffer-create buffer))))
-	   (narrow (get bufintern 'narrow))
-	   (frozen (get bufintern 'frozen))
+	   (bufintern) 
+	   (nbuf (get-buffer buffer))
+	   (narrow)
+	   (frozen)
 	   (spoint nil))
-      (set-buffer (get-buffer buffer))
-;;;
-;;; have to use this kludge because save-restriction
-;;; doesn't work right, it keeps distance between point
-;;; and point-max a constant, not the distance between
-;;; point and mark, seesh mta Fri Jan  3 12:43:01 EET 1992
-;;;
+
+      (if (not nbuf)
+	  (save-excursion
+	    (setq nbuf (irchat-get-buffer-create buffer))
+	    (set-buffer nbuf)
+	    (irchat-Dialogue-mode)))
+	  
+      (setq bufintern (intern (format "%s" nbuf) irchat-obarray))
+      (setq narrow (get bufintern 'narrow))
+      (setq frozen (get bufintern 'frozen))
+      (set-buffer nbuf)
+      ;;
+      ;; have to use this kludge because save-restriction
+      ;; doesn't work right, it keeps distance between point
+      ;; and point-max a constant, not the distance between
+      ;; point and mark, seesh mta Fri Jan  3 12:43:01 EET 1992
+      ;;
       (if narrow
 	  (progn
 	    (setq spoint (point))
@@ -645,51 +659,53 @@ One is for entering commands and text, the other displays the IRC dialogue."
 				 win)
 		(set-window-start win (point))
 		(goto-char (point-max))))))
-      (set-buffer obuf)
-      )
-    nil)
-  )
+      (set-buffer obuf))
+    nil))
+
 
 (defun irchat-get-buffer-create (name)
   "Get or create buffer, keep track on its name so we can kill it."
-  (if (not (memq name irchat-buffer-list))
+  (if (not (member name irchat-buffer-list))
       (setq irchat-buffer-list (append (list name) irchat-buffer-list)))
   (get-buffer-create name))
 
+
 (defun irchat-freeze-toggle (buffer)
   (interactive "b")
-  (let* ( (intern-buffer (intern (format "%s" (get-buffer buffer))))
-	  (buffer-frozen (get intern-buffer 'frozen))
-	  )
+  (let* ((intern-buffer (intern (format "%s" (get-buffer buffer)) 
+				irchat-obarray))
+	 (buffer-frozen (get intern-buffer 'frozen)))
     (if buffer-frozen
 	(put intern-buffer 'frozen nil)
-      (put intern-buffer 'frozen t))
-    ))
+      (put intern-buffer 'frozen t))))
+
 
 (defun irchat-frozen (buffer)
   (interactive "b")
-  (let* ( (intern-buffer (intern (format "%s" (get-buffer buffer))))
-	  (buffer-frozen (get intern-buffer 'frozen))
-	  )
+  (let* ((intern-buffer (intern (format "%s" (get-buffer buffer)) 
+				irchat-obarray))
+	 (buffer-frozen (get intern-buffer 'frozen)))
     buffer-frozen))
 
+
 (defun irchat-ownfreeze-toggle (buffer)
   (interactive "b")
-  (let* ( (intern-buffer (intern (format "%s" (get-buffer buffer))))
-	  (buffer-ownfrozen (get intern-buffer 'ownfrozen))
-	  )
+  (let* ((intern-buffer (intern (format "%s" (get-buffer buffer)) 
+				irchat-obarray))
+	 (buffer-ownfrozen (get intern-buffer 'ownfrozen)))
     (if buffer-ownfrozen
 	(put intern-buffer 'ownfrozen nil)
-      (put intern-buffer 'ownfrozen t))
-    ))
+      (put intern-buffer 'ownfrozen t))))
+
 
 (defun irchat-ownfrozen (buffer)
   (interactive "b")
-  (let* ( (intern-buffer (intern (format "%s" (get-buffer buffer))))
-	  (buffer-ownfrozen (get intern-buffer 'ownfrozen))
-	  )
+  (let* ((intern-buffer (intern (format "%s" (get-buffer buffer)) 
+				irchat-obarray))
+	 (buffer-ownfrozen (get intern-buffer 'ownfrozen)))
     buffer-ownfrozen))
 
+
 (defun irchat-check-buffers ()
   (if (> irchat-buffer-maxsize 0)
       (let ((buflist irchat-buffer-list)
@@ -700,16 +716,9 @@ One is for entering commands and text, the other displays the IRC dialogue."
 	      (let ((buffer-read-only nil))
 		(goto-char (- (buffer-size) irchat-buffer-defsize))
 		(forward-line -1)
-		(delete-region (point-min) (point))
-		)
-	    )
-	  (setq buflist (cdr buflist))
-	  )
-	(set-buffer obuf)
-	)
-    )
-  )
-
+		(delete-region (point-min) (point))))
+	  (setq buflist (cdr buflist)))
+	(set-buffer obuf))))
 ;;;
 ;;; eof
 ;;;
